$input v_normal, v_pos, v_texcoord0

#include "common.sh"

uniform vec4 u_diffuseColor;
uniform vec4 u_specularMaterial;
uniform vec4 u_shininess;

uniform vec4 u_ambientColor;

uniform vec4 u_lightPosDir;
uniform vec4 u_lightPosPoint1;
uniform vec4 u_lightPosPoint2;

uniform vec4 u_colorDir;
uniform vec4 u_colorP1;
uniform vec4 u_colorP2;

uniform vec4 u_intensityDir;
uniform vec4 u_intensityP1;
uniform vec4 u_intensityP2;

void main(){
    vec3 normal = normalize(v_normal);
    vec3 viewDir = normalize(-v_pos);

    vec4 inputColor = toLinear(u_diffuseColor);
    float alphaCorrect = 1.0 / inputColor.a;
    // Correct for premultiplied alpha
    inputColor = vec4 (inputColor.r * alphaCorrect, inputColor.g * alphaCorrect, inputColor.b * alphaCorrect, inputColor.a);

    vec4 specularMaterial = toLinear(u_specularMaterial);
    vec4 ambientColor = toLinear(u_ambientColor);

    // Calculate directional light
    vec3 directionalLightDir = normalize(-u_lightPosDir.xyz);
    vec4 result1 = CalcDirLight(directionalLightDir, normal, viewDir,
                                inputColor, specularMaterial, vec4(1.0,1.0,1.0,specularMaterial.a), u_shininess.x,
                                ambientColor, toLinear(u_colorDir), u_intensityDir.x);

    // Fist point light
    vec3 pointLight1Dir = normalize(u_lightPosPoint1.xyz-v_pos);
    float distance1 = length(u_lightPosPoint1.xyz-v_pos) * 0.001;
    vec4 result2 = CalcPointLight(pointLight1Dir, distance1, normal, viewDir,
                                  inputColor, specularMaterial, vec4(1.0,1.0,1.0,specularMaterial.a), u_shininess.x,
                                  ambientColor, toLinear(u_colorP1), u_intensityP1.x);

    // Second point light
    vec3 pointLight2Dir = normalize(u_lightPosPoint2.xyz-v_pos);
    float distance2 = length(u_lightPosPoint2.xyz-v_pos) * 0.001;
    vec4 result3 = CalcPointLight(pointLight2Dir, distance2, normal, viewDir,
                                  inputColor, specularMaterial, vec4(1.0,1.0,1.0,specularMaterial.a), u_shininess.x,
                                  ambientColor, toLinear(u_colorP2), u_intensityP2.x);

    vec4 result = result1 + result2 + result3;
    gl_FragColor = toGamma(vec4(result.r * inputColor.a, result.g * inputColor.a, result.b * inputColor.a, inputColor.a));
}